==> cupboard-0.1.1.tgz: package/lib/index.js <==
var bootstrap = require('./bootstrap'),
printMessages = require('./utils/printMessages'),
Structr = require('structr'),
step = require('step');
 
/**
 * executes command from CLI
 */

function execute2(ops, router) {
	
	//execute given command against the projects first. Dun worry, 
	//default commands act as middleware before they get to the projects. Why?
	//take this for an example:
	//cbd publish some-project, where the default command "publish" executes a project
	//command, but then waits until SUCCESS before updating the last modified date in the cupboard db.
	
	var steps = [];
	
	ops.command.split('+').forEach(function(command) {
			
		steps.push(function()
		{
			var next = this;
			
			router.pull('command/execute/' + command, Structr.copy(ops), function(response) {

				if(response) {

					if(response.errors) printMessages(response.errors, 'red');
					if(response.warnings) printMessages(response.warnings, 'yellow');
					if(response.messages) printMessages(response.messages, response.result ? response.result.color : null);
				}
				
				next();
			});
		});
	});
	
	step.apply(null, steps);
	
}

var execute = exports.execute = function(ops) {
	
	bootstrap.init(function(router) {
		
		var cops = Structr.copy(ops);
		
		execute2(ops, router);
		
		var target = cops.args[0] || (cops.all ? '--all' : null);
		
		//flag to watch all projects for changes
		if(ops.watch && target) {
			
			console.log('Watching target projects for any changes'.grey);
			
			getProjects(target, function(err, projects) {
			
				if(err) return; 
				
				projects.forEach(function(project)
				{
					project.watch().on('change', function()
					{       
						console.log('%s has changed, re-executing'.grey, project.name().bold);
						  
						cops.args[0] = project.name();
						cops.all = false; 
						 
						execute2(cops, router);
					});
				});
			});
		}
		
	});
}

/**
 * Returns all projects in cupboard
 */

var getProjects = exports.getProjects = function(projects, callback) {
	
	if(!(projects instanceof Array)) projects = projects.split('+');
	
	bootstrap.init(function(router) {
		
		router.pull('projects', { target: projects.join('+') }, function(response) {
			callback(false, response.result ? response.result : null);
		})
	});
}

==> cupboard-0.1.2.tgz: package/lib/index.js <==
var bootstrap = require('./bootstrap'),
printMessages = require('./utils/printMessages'),
Structr = require('structr'),
step = require('step');
 
/**
 * executes command from CLI
 */

function execute2(ops, router) {
	
	//execute given command against the projects first. Dun worry, 
	//default commands act as middleware before they get to the projects. Why?
	//take this for an example:
	//cbd publish some-project, where the default command "publish" executes a project
	//command, but then waits until SUCCESS before updating the last modified date in the cupboard db.
	
	var steps = [];
	
	ops.command.split('+').forEach(function(command) {
		
		
		steps.push(function()
		{
			var next = this,
			cops = Structr.copy(ops);
			cops.command = command;
			
			
			router.pull('command/execute/' + command, cops, function(response) {
				
				if(response) {

					if(response.errors) printMessages(response.errors, 'red');
					if(response.warnings) printMessages(response.warnings, 'yellow');
					if(response.messages) printMessages(response.messages, response.result ? response.result.color : null);
				}
				
				next();
			});
		});
	});
	
	step.apply(null, steps);
	
}

var execute = exports.execute = function(ops) {
	
	bootstrap.init(function(router) {
		
		var cops = Structr.copy(ops);
		
		execute2(ops, router);
		
		var target = cops.args[0] || (cops.all ? '--all' : null);
		
		//flag to watch all projects for changes
		if(ops.watch && target) {
			
			console.log('Watching target projects for any changes'.underline);
			
			getProjects(target, function(err, projects) {
			
				if(err) return; 
				
				projects.forEach(function(project)
				{
					project.watch().on('change', function()
					{       
						console.log('%s has changed, re-executing'.grey, project.name().bold);
						  
						cops.args[0] = project.name();
						cops.all = false; 
						 
						execute2(cops, router);
					});
				});
			});
		}
		
	});
}

/**
 * Returns all projects in cupboard
 */

var getProjects = exports.getProjects = function(projects, callback) {
	
	if(!(projects instanceof Array)) projects = projects.split('+');
	
	bootstrap.init(function(router) {
		
		router.pull('projects', { target: projects.join('+') }, function(response) {
			callback(false, response.result ? response.result : null);
		})
	});
}
